Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(338)

Unified Diff: media/filters/decrypting_audio_decoder.h

Issue 416333011: Allow setContentDecryptionModule() to get called when setting is done. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: rebase + android tweaks Created 6 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « media/filters/audio_decoder_selector_unittest.cc ('k') | media/filters/decrypting_audio_decoder.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/filters/decrypting_audio_decoder.h
diff --git a/media/filters/decrypting_audio_decoder.h b/media/filters/decrypting_audio_decoder.h
index 70cbc5632268c13130e6e6231bc6901a43b80f69..9ea211a1ab9f7bae4ab9f91d58db31912b9508f3 100644
--- a/media/filters/decrypting_audio_decoder.h
+++ b/media/filters/decrypting_audio_decoder.h
@@ -66,8 +66,10 @@ class MEDIA_EXPORT DecryptingAudioDecoder : public AudioDecoder {
kError
};
- // Callback for DecryptorHost::RequestDecryptor().
- void SetDecryptor(Decryptor* decryptor);
+ // Callback for DecryptorHost::RequestDecryptor(). |decryptor_attached_cb| is
+ // called when the decryptor has been completely attached to the pipeline.
+ void SetDecryptor(Decryptor* decryptor,
+ const DecryptorAttachedCB& decryptor_attached_cb);
// Initializes the audio decoder on the |decryptor_| with |config_|.
void InitializeDecoder();
« no previous file with comments | « media/filters/audio_decoder_selector_unittest.cc ('k') | media/filters/decrypting_audio_decoder.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698